@@ -249,16 +249,7 @@ class WorkbenchWindow(ApplicationWindow):
     def _layout_default(self):
         """ Trait initializer. """
 
-        layout = WorkbenchWindowLayout(window=self)
-
-        # Wire up event handlers.
-        #
-        # fixme: I *hate* calling event handlers manually, but this is such a
-        # common pattern... Maybe a '@on_trait_initialized' decorator is in
-        # order?
-        self._layout_changed(None, layout)
-
-        return layout
+        return WorkbenchWindowLayout(window=self)
     
     #### Methods ##############################################################
 
@@ -752,9 +743,6 @@ class WorkbenchWindow(ApplicationWindow):
             view = self.get_view_by_id(active_view_id)
             if view is not None:
                 self.active_view = view
-                
-            if not self.show_editor_area:
-                self.active_editor = None
         
         # Otherwise, this is the first time the perspective has been seen
         # so create it.
@@ -770,13 +758,15 @@ class WorkbenchWindow(ApplicationWindow):
             # perspective.
             self.active_view = None
 
-            # Show the editor area?
-            if new.show_editor_area:
-                self.show_editor_area()
+        # Show the editor area?
+        if new.show_editor_area:
+            self.show_editor_area()
+        else:
+            self.hide_editor_area()
+            self.active_editor = None
 
-            else:
-                self.hide_editor_area()
-                self.active_editor = None
+        # Inform the perspective that it has been shown.
+        new.show(self)
             
         # This forces the dock window to update its layout.
         if old is not None:
@@ -841,36 +831,6 @@ class WorkbenchWindow(ApplicationWindow):
         self.active_part = new
 
         return
-
-    def _editors_items_changed(self, event):
-        """ Static trait change handler. """
-
-        for editor in event.removed:
-            editor.on_trait_change(
-                self._on_editor_has_focus_changed, 'has_focus', remove=True
-            )
-
-        for editor in event.added:
-            editor.on_trait_change(
-                self._on_editor_has_focus_changed, 'has_focus'
-            )
-
-        return
-    
-    def _layout_changed(self, old, new):
-        """ Static trait change handler. """
-
-        if old is not None:
-            old.on_trait_change(
-                self._on_editor_closed, 'editor_closed', remove=True
-            )
-
-        if new is not None:
-            new.on_trait_change(
-                self._on_editor_closed, 'editor_closed'
-            )
-
-        return
         
     def _views_changed(self, old, new):
         """ Static trait change handler. """
@@ -900,31 +860,33 @@ class WorkbenchWindow(ApplicationWindow):
 
     #### Dynamic ####
 
+    @on_trait_change('layout.editor_closed')
     def _on_editor_closed(self, editor):
         """ Dynamic trait change handler. """
 
-        self.editors.remove(editor)
+        index = self.editors.index(editor)
+        del self.editors[index]
         if editor is self.active_editor:
             if len(self.editors) > 0:
+                index = min(index, len(self.editors) - 1)
                 # If the user closed the editor manually then this method is
                 # being called from a toolkit-specific event handler. Because
                 # of that we have to make sure that we don't change the focus
                 # from within this method directly hence we activate the editor
                 # later in the GUI thread.
-                GUI.invoke_later(self.activate_editor, self.editors[0])
+                GUI.invoke_later(self.activate_editor, self.editors[index])
 
             else:
                 self.active_editor = None
 
         return
 
-    #@on_trait_change('editors.has_focus')
+    @on_trait_change('editors.has_focus')
     def _on_editor_has_focus_changed(self, obj, trait_name, old, new):
         """ Dynamic trait change handler. """
 
         if trait_name == 'has_focus' and new:
             self.active_editor = obj
-            self.active_part   = obj
                 
         return
 
@@ -934,7 +896,6 @@ class WorkbenchWindow(ApplicationWindow):
 
         if trait_name == 'has_focus' and new:
             self.active_view = obj
-            self.active_part = obj
 
         return
 
